FirebasePackage class final

Core class.

Constructors

FirebasePackage({required String packageName, required String displayName, required String category, required String documentationUrl, required String description})
const

Properties

category String
Public property or field.
final
description String
Public property or field.
final
displayName String
Public property or field.
final
documentationUrl String
Public property or field.
final
hashCode int
The hash code for this object.
no setterinherited
packageName String
Public property or field.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromPackageName(String name) FirebasePackage?