IOSAnalyzer class final

Core class.

Inheritance

Constructors

IOSAnalyzer({PlistParser? plistParser, PodfileParser? podfileParser, PodfileLockParser? podfileLockParser, PbxprojParser? pbxprojParser})

Properties

category String
Public property or field.
no setteroverride
description String
Public property or field.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
name String
Public property or field.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

analyze(AnalyzerContext context) Future<DiagnosticResult>
Public method or function.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited