Command class abstract

Core class.

Implementers

Constructors

Command()

Properties

aliases List<String>
no setter
description String
Public property or field.
no setter
hashCode int
The hash code for this object.
no setterinherited
name String
Public property or field.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute(List<String> args) Future<int>
Public method or function.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited