CommandRunner class final

Core class.

Constructors

CommandRunner({required Logger logger, required Terminal terminal, required FileSystem fileSystem})

Properties

fileSystem FileSystem
Public property or field.
final
hashCode int
The hash code for this object.
no setterinherited
logger Logger
Public property or field.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terminal Terminal
Public property or field.
final

Methods

findCommand(String name) Command?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printUsage() → void
Public method or function.
register(Command command) → void
Public method or function.
registerAll(List<Command> commands) → void
Public method or function.
run(List<String> args) Future<int>
Public method or function.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited