ReportCommand class final

Core class.

Inheritance

Constructors

ReportCommand({required Logger logger, required Terminal terminal, required FileSystem fileSystem, required AnalyzerService analyzerService})

Properties

aliases List<String>
no setterinherited
analyzerService AnalyzerService
Public property or field.
final
description String
Public property or field.
no setteroverride
fileSystem FileSystem
Public property or field.
final
hashCode int
The hash code for this object.
no setterinherited
logger Logger
Public property or field.
final
name String
Public property or field.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terminal Terminal
Public property or field.
final

Methods

execute(List<String> args) Future<int>
Public method or function.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited