FireDoctorException class final

Core class.

Implemented types

Constructors

FireDoctorException(String message, {String? code, StackTrace? stackTrace})
const

Properties

code String?
Public property or field.
final
hashCode int
The hash code for this object.
no setterinherited
message String
Public property or field.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
Public property or field.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Public method or function.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited