FileSystem class abstract
Core class.
- Implementers
Constructors
Properties
- currentDirectory → String
-
Public property or field.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copy(
String source, String destination) → Future< void> - Public method or function.
-
createDirectory(
String path) → Future< void> - Public method or function.
-
delete(
String path) → Future< void> - Public method or function.
-
exists(
String path) → bool - Public method or function.
-
isDirectory(
String path) → bool - Public method or function.
-
isFile(
String path) → bool - Public method or function.
-
join(
String part1, [String? part2, String? part3]) → String - Public method or function.
-
listDirectory(
String path) → List< String> - Public method or function.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readAsString(
String path) → String - Public method or function.
-
readAsStringAsync(
String path) → Future< String> - Public method or function.
-
toString(
) → String -
A string representation of this object.
inherited
-
writeAsString(
String path, String content) → void - Public method or function.
-
writeAsStringAsync(
String path, String content) → Future< void> - Public method or function.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited