LocalFileSystem class final

Core class.

Implemented types

Constructors

LocalFileSystem()
const

Properties

currentDirectory String
Public property or field.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copy(String source, String destination) Future<void>
Public method or function.
override
createDirectory(String path) Future<void>
Public method or function.
override
delete(String path) Future<void>
Public method or function.
override
exists(String path) bool
Public method or function.
override
isDirectory(String path) bool
Public method or function.
override
isFile(String path) bool
Public method or function.
override
join(String part1, [String? part2, String? part3]) String
Public method or function.
override
listDirectory(String path) List<String>
Public method or function.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readAsString(String path) String
Public method or function.
override
readAsStringAsync(String path) Future<String>
Public method or function.
override
toString() String
A string representation of this object.
inherited
writeAsString(String path, String content) → void
Public method or function.
override
writeAsStringAsync(String path, String content) Future<void>
Public method or function.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited