AnalyzerConfidence class final

Core class.

Constructors

AnalyzerConfidence({required String code, required double confidence, required String reasoning})
const

Properties

code String
Public property or field.
final
confidence double
Public property or field.
final
hashCode int
The hash code for this object.
no setterinherited
reasoning String
Public property or field.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Public method or function.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

defaults Map<String, AnalyzerConfidence>
no setter