CheckStatus class sealed

Core class.

Properties

hashCode int
The hash code for this object.
no setterinherited
isFailed bool
no setter
isPassed bool
no setter
isWarning bool
no setter
label String
Public property or field.
no setter
name String
Public property or field.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromName(String name) CheckStatus

Constants

failed → const _CheckStatusFailed
notApplicable → const _CheckStatusNotApplicable
passed → const _CheckStatusPassed
skipped → const _CheckStatusSkipped
warning → const _CheckStatusWarning