HealthScore class final

Core class.

Constructors

HealthScore({required double overallScore, required List<CategoryScore> categoryScores, required Map<PriorityGroup, List<DiagnosticIssue>> priorityGroups, required List<Recommendation> recommendations, required int totalWeight, required int maxPossibleWeight, required ScoreWeights weights})
const

Properties

categoryScores List<CategoryScore>
Public property or field.
final
criticalIssues List<DiagnosticIssue>
no setter
hashCode int
The hash code for this object.
no setterinherited
highPriorityIssues List<DiagnosticIssue>
no setter
lowPriorityIssues List<DiagnosticIssue>
no setter
maxPossibleWeight int
Public property or field.
final
mediumPriorityIssues List<DiagnosticIssue>
no setter
overallScore double
Public property or field.
final
priorityGroups Map<PriorityGroup, List<DiagnosticIssue>>
Public property or field.
final
recommendations List<Recommendation>
Public property or field.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalIssues int
no setter
totalWeight int
Public property or field.
final
weights ScoreWeights
Public property or field.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Public method or function.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited