ScoreWeights class final

Core class.

Constructors

ScoreWeights({int critical = 25, int error = 15, int warning = 5, int info = 1})
const

Properties

critical int
Public property or field.
final
error int
Public property or field.
final
hashCode int
The hash code for this object.
no setterinherited
info int
Public property or field.
final
maxScorePerIssue int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
warning int
Public property or field.
final

Methods

copyWith({int? critical, int? error, int? warning, int? info}) ScoreWeights
Public method or function.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
weightFor(Severity severity) int
Public method or function.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultWeights → const ScoreWeights