Severity class sealed

Core class.

Implemented types

Properties

emoji String
Public property or field.
no setter
hashCode int
The hash code for this object.
no setterinherited
label String
Public property or field.
no setter
name String
Public property or field.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
Public property or field.
no setter

Methods

compareTo(Severity other) int
Public method or function.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) Severity

Constants

critical → const _SeverityCritical
error → const _SeverityError
info → const _SeverityInfo
warning → const _SeverityWarning