ValidationReport class final

Core class.

Constructors

ValidationReport({required List<ValidationEntry> entries, required DateTime generatedAt})
const

Properties

analyzerPrecision Map<String, double>
no setter
analyzerRecall Map<String, double>
no setter
entries List<ValidationEntry>
Public property or field.
final
generatedAt DateTime
Public property or field.
final
hashCode int
The hash code for this object.
no setterinherited
overallAccuracy double
no setter
overallPrecision double
no setter
overallRecall double
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalFalseNegatives int
no setter
totalFalsePositives int
no setter
totalTruePositives int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonString() String
Public method or function.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited