HealthScoreEngine class final

Core class.

Constructors

HealthScoreEngine({ScoreWeights weights = const ScoreWeights(), int maxRecommendations = 3})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
maxRecommendations int
Public property or field.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
weights ScoreWeights
Public property or field.
final

Methods

compute(DiagnosticReport report) HealthScore
Public method or function.
computeFromResults(List<DiagnosticResult> results) HealthScore
Public method or function.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

categoryDisplayNames → const Map<String, String>