ValidationRunner class final

Core class.

Constructors

ValidationRunner({required AnalyzerService analyzerService, required FileSystem fileSystem, Logger? logger})

Properties

analyzerService AnalyzerService
Public property or field.
final
fileSystem FileSystem
Public property or field.
final
hashCode int
The hash code for this object.
no setterinherited
logger Logger?
Public property or field.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConfidenceByCategory() Map<String, double>
Returns average confidence grouped by analyzer category
getConfidenceScores() Map<String, double>
Public method or function.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
runAll({String? projectsDir}) Future<ValidationReport>
Public method or function.
saveReport(ValidationReport report, String outputPath) Future<void>
Public method or function.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited