ValidationService class

Core class.

Constructors

ValidationService({required AnalyzerService analyzerService, required FileSystem fileSystem, Logger? logger})

Properties

analyzerService AnalyzerService
Public property or field.
final
fileSystem FileSystem
Public property or field.
final
hashCode int
The hash code for this object.
no setterinherited
logger Logger?
Public property or field.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

loadExpectedFindings(String projectPath) Future<List<ExpectedFinding>>
Load expected findings from a project's expected_findings.json
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validateAll(String projectsDir, {Logger? progressLogger}) Future<ValidationReport>
Validate all projects in a directory
validateProject(String projectPath) Future<ValidationEntry>
Run all analyzers on a single project and produce a ValidationEntry

Operators

operator ==(Object other) bool
The equality operator.
inherited