SourceFileCache class
Core class.
Constructors
Properties
- fs → FileSystem
-
Public property or field.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getCleaned(
String filePath) → String? -
getContent(
String filePath) → String? -
getDartFiles(
String projectPath) → List< String> - Public method or function.
-
getLines(
String filePath) → List< String> ? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
) → void - Public method or function.
-
scanProject(
String projectPath) → void - Public method or function.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited