AnalyzerContext class final
Core class.
Constructors
-
AnalyzerContext({required String projectPath, required FileSystem fileSystem, Map<
String, String> configuration = const {}, SourceFileCache? sourceFileCache})
Properties
-
configuration
→ Map<
String, String> -
Public property or field.
final
- fileSystem → FileSystem
-
Public property or field.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- projectPath → String
-
Public property or field.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceFileCache → SourceFileCache?
-
Public property or field.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited