FirebasePackage class final
Core class.
Constructors
Properties
- category → String
-
Public property or field.
final
- description → String
-
Public property or field.
final
- displayName → String
-
Public property or field.
final
- documentationUrl → String
-
Public property or field.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- packageName → String
-
Public property or field.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromPackageName(
String name) → FirebasePackage?
Constants
-
all
→ const List<
FirebasePackage> - analytics → const FirebasePackage
- appCheck → const FirebasePackage
- auth → const FirebasePackage
- cloudFirestore → const FirebasePackage
- core → const FirebasePackage
- crashlytics → const FirebasePackage
- database → const FirebasePackage
- messaging → const FirebasePackage
- remoteConfig → const FirebasePackage
- storage → const FirebasePackage