Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
exitCodeForSeverityRank(
int mostSevereRank) → int - Map the most severe issue rank to the appropriate exit code.
Constants
- description → const String
- exitCriticalIssues → const int
- Critical issues found.
- exitErrorsOnly → const int
- Error issues found (no critical).
- exitFailure → const int
- Deprecated: use exitInternalFailure instead (value 4).
- exitInternalFailure → const int
- Internal FireDoctor failure (e.g. crash, invalid args).
- exitNoIssues → const int
- No issues found — all checks passed.
- exitSuccess → const int
- Deprecated: use exitNoIssues instead (value 0).
- exitWarningsOnly → const int
- Only warning issues found (no errors or critical).
- githubUrl → const String
- jsonSchemaVersion → const String
- maxLineWidth → const int
- packageName → const String
- version → const String