DiagnosticIssue class final
Core class.
Constructors
Properties
- code → String
-
Public property or field.
final
- description → String
-
Public property or field.
final
- filePath → String?
-
Public property or field.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lineNumber → int?
-
Public property or field.
final
-
metadata
→ Map<
String, String> ? -
Public property or field.
final
- recommendation → String?
-
Public property or field.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- severity → Severity
-
Public property or field.
final
- title → String
-
Public property or field.
final
Methods
-
copyWith(
{Severity? severity, String? code, String? title, String? description, String? recommendation()?, String? filePath()?, int? lineNumber()?, Map< String, String> ? metadata()?}) → DiagnosticIssue - Public method or function.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited