DiagnosticReport class final
Core class.
Constructors
-
DiagnosticReport({required String projectName, required String projectPath, required DateTime createdAt, required List<
DiagnosticResult> results, String? firebaseVersion, Map<String, String> environment = const {}, HealthScore? healthScore}) -
const
Properties
- createdAt → DateTime
-
Public property or field.
final
-
environment
→ Map<
String, String> -
Public property or field.
final
- exitCode → int
-
CI-friendly exit code:
0 = no issues
1 = warnings only
2 = errors (but no critical)
3 = critical issues
no setter
- firebaseVersion → String?
-
Public property or field.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- healthScore → HealthScore?
-
Public property or field.
final
- mostSevereRank → int
-
The highest severity rank across all results.
0 = no issues, 1 = info only, 2 = warnings, 3 = errors, 4 = critical.
no setter
- passed → bool
-
Public method or function.
no setter
- projectName → String
-
Public property or field.
final
- projectPath → String
-
Public property or field.
final
-
results
→ List<
DiagnosticResult> -
Public property or field.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- score → double
-
no setter
- totalErrors → int
-
Public method or function.
no setter
- totalIssues → int
-
Public method or function.
no setter
- totalWarnings → int
-
Public method or function.
no setter
Methods
-
computeHealthScore(
{HealthScoreEngine? engine}) → DiagnosticReport -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited