PriorityGroup enum
Values
- critical → const PriorityGroup
-
const PriorityGroup('Critical Fixes', 0) - high → const PriorityGroup
-
const PriorityGroup('High Priority', 1) - medium → const PriorityGroup
-
const PriorityGroup('Medium Priority', 2) - low → const PriorityGroup
-
const PriorityGroup('Low Priority', 3)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- label → String
-
Public property or field.
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - rank → int
-
Public property or field.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromSeverity(
Severity severity) → PriorityGroup
Constants
-
values
→ const List<
PriorityGroup> - A constant List of the values in this enum, in order of their declaration.