Pubspec class final
Core class.
Constructors
Properties
- dartSdkConstraint → String?
-
Public property or field.
final
-
dependencies
→ Map<
String, String> -
Public property or field.
final
- description → String?
-
Public property or field.
final
-
devDependencies
→ Map<
String, String> -
Public property or field.
final
- flutterSdkConstraint → String?
-
Public property or field.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isFlutterProject → bool
-
Public property or field.
final
- name → String
-
Public property or field.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → String?
-
Public property or field.
final
Methods
-
dependencyVersion(
String packageName) → String? -
hasDependency(
String packageName) → bool - Public method or function.
-
hasDevDependency(
String packageName) → bool - Public method or function.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited