ValidationEntry class final
Core class.
Constructors
-
ValidationEntry({required String projectName, required String projectPath, required int totalChecks, required List<
ExpectedFinding> truePositives, required List<ExpectedFinding> falseNegatives, required List<DiagnosticIssue> falsePositives, required double accuracy, required double precision, required double recall}) -
const
Properties
- accuracy → double
-
Public property or field.
final
-
falseNegatives
→ List<
ExpectedFinding> -
Public property or field.
final
-
falsePositives
→ List<
DiagnosticIssue> -
Public property or field.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- precision → double
-
Public property or field.
final
- projectName → String
-
Public property or field.
final
- projectPath → String
-
Public property or field.
final
- recall → double
-
Public property or field.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalActual → int
-
no setter
- totalChecks → int
-
Public property or field.
final
- totalExpected → int
-
no setter
-
truePositives
→ List<
ExpectedFinding> -
Public property or field.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Public method or function.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited