AnalyzerService class
Core class.
Constructors
- AnalyzerService({required Logger logger})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- logger → Logger
-
Public property or field.
final
-
registeredAnalyzers
→ List<
Analyzer> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
Analyzer analyzer) → void - Public method or function.
-
registerAll(
List< Analyzer> analyzers) → void - Public method or function.
-
runAll(
AnalyzerContext context, {Logger? progressLogger}) → Future< List< DiagnosticResult> > - Public method or function.
-
runAnalyzer(
Analyzer analyzer, AnalyzerContext context, {Logger? progressLogger}) → Future< DiagnosticResult> - Public method or function.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited