ReportService class final
Core class.
Constructors
- ReportService({required Terminal terminal, HealthScoreEngine healthScoreEngine = const HealthScoreEngine()})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- healthScoreEngine → HealthScoreEngine
-
Public property or field.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- terminal → Terminal
-
Public property or field.
final
Methods
-
generateReport(
{required List< DiagnosticResult> results, String? projectName, String? projectPath, String? firebaseVersion, Map<String, String> ? environment, bool computeHealthScore = true}) → DiagnosticReport -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
printReport(
DiagnosticReport report) → void - Public method or function.
-
saveReport(
DiagnosticReport report, FileSystem fs, String outputPath) → Future< void> - Public method or function.
-
toJson(
DiagnosticReport report) → String - Public method or function.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited