Terminal class abstract
Core class.
- Implementers
Constructors
- Terminal()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clear(
) → void - Public method or function.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readLine(
) → String? -
toString(
) → String -
A string representation of this object.
inherited
-
write(
String message) → void - Public method or function.
-
writeError(
String message) → void - Public method or function.
-
writeInfo(
String message) → void - Public method or function.
-
writeLine(
String message) → void - Public method or function.
-
writeSuccess(
String message) → void - Public method or function.
-
writeWarning(
String message) → void - Public method or function.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited